@@ -4,21 +4,21 @@ mod api_key;
 mod basic;
 mod bearer;
 
-use poem::Request;
+use poem::{Request, Result};
 
 pub use self::{api_key::ApiKey, basic::Basic, bearer::Bearer};
-use crate::{base::UrlQuery, registry::MetaParamIn, ParseRequestError};
+use crate::{base::UrlQuery, registry::MetaParamIn};
 
 /// Represents a basic authorization extractor.
 pub trait BasicAuthorization: Sized {
     /// Extract from the HTTP request.
-    fn from_request(req: &Request) -> Result<Self, ParseRequestError>;
+    fn from_request(req: &Request) -> Result<Self>;
 }
 
 /// Represents a bearer authorization extractor.
 pub trait BearerAuthorization: Sized {
     /// Extract from the HTTP request.
-    fn from_request(req: &Request) -> Result<Self, ParseRequestError>;
+    fn from_request(req: &Request) -> Result<Self>;
 }
 
 /// Represents an api key authorization extractor.
@@ -29,5 +29,5 @@ pub trait ApiKeyAuthorization: Sized {
         query: &UrlQuery,
         name: &str,
         in_type: MetaParamIn,
-    ) -> Result<Self, ParseRequestError>;
+    ) -> Result<Self>;
 }
